# compile markdown using pandoc
# params:
# 1: input file
# 2: pandoc template
# 3: output format
# 4: output file
compile_md = pandoc \
	$(1) \
	--standalone \
	--from markdown \
	--to $(3) \
	--template $(2) \
	$(addprefix --variable ,$(PANDOCVARS)) \
	$(PANDOCFLAGS) \
	--output $(4)

GSFLAGS := \
	-sDEVICE=pdfwrite \
	-dNOOUTERSAVE \
	-dNOPAUSE \
	-dQUIET \
	-dBATCH

# post-process and compress PDF files
# params:
# 1: input file
# 2: output file
postprocess_pdf = gs \
	$(GSFLAGS) \
	-sPAPERSIZE=a4 \
	-dFIXEDMEDIA \
	-dPDFFitPage \
	-dCompatibilityLevel=1.7 \
	-dPDFSETTINGS=/ebook \
	-sOutputFile=$(2) \
	$(1)

# convert PDF to PDF/A 2-b
# params:
# 1: input file
# 2: output file
convert_pdfa = /opt/pdfa/bin/gs-919-linux_x86_64 \
	$(GSFLAGS) \
	-dPDFA=2 \
	-sProcessColorModel=DeviceRGB \
	-dPDFACompatibilityPolicy=1 \
	-sOutputFile=$(2) \
	/opt/pdfa/PDFA_def.ps \
	$(1)

# convert markdown to PDF
# params:
# 1: input file
# 2: pandoc template
# 3: output file
md2pdf = $(call compile_md,$(1),$(2),pdf,-) | $(call postprocess_pdf,-,$(3))

# convert markdown to PDF/A 2-b
# 1: input file
# 2: pandoc template
# 3: output file
md2pdfa = $(call md2pdf,$(1),$(2),-) | $(call convert_pdfa,-,$(3))
